@@ -71,6 +71,7 @@ Sobby::Server::Server(int argc, char* argv[]):
 	std::string autosave_file;
 	std::string autosave_folder;
 	int autosave_interval;
+	std::string post_save_hook;
 
 	std::string config_file_read;
 	std::string config_file_write;
@@ -130,6 +131,11 @@ Sobby::Server::Server(int argc, char* argv[]):
 		autosave_interval = entry.get_value<unsigned int>(
 			"autosave_interval", 0
 		);
+
+		post_save_hook = entry.get_value<std::string>(
+			"post_save_hook", ""
+		);
+
 		password = entry.get_value<Glib::ustring>("password", "");
 
 		m_command_dir = entry.get_value<Glib::ustring>(
@@ -146,6 +152,7 @@ Sobby::Server::Server(int argc, char* argv[]):
 		autosave_folder = "";
 		autosave_file = "autosave.obby";
 		autosave_interval = 0;
+		post_save_hook = "";
 		password = "";
 		m_command_dir = "";
 		session = "";
@@ -195,6 +202,14 @@ Sobby::Server::Server(int argc, char* argv[]):
 		"Interval (in seconds) between autosaves; 0 disables autosave"
 	);
 
+	Glib::OptionEntry opt_common_post_save_hook;
+	opt_common_post_save_hook.set_long_name("post-save-hook");
+	opt_common_post_save_hook.set_arg_description("FILE");
+	opt_common_post_save_hook.set_description(
+		"Executable to be executed every time the file specified "
+		"in autosave-file has been written"
+	);
+
 	Glib::OptionEntry opt_common_command_dir;
 	opt_common_command_dir.set_long_name("command-directory");
 	opt_common_command_dir.set_arg_description("DIRECTORY");
@@ -243,6 +258,11 @@ Sobby::Server::Server(int argc, char* argv[]):
 		autosave_interval
 	);
 
+	opt_group_common.add_entry_filename(
+		opt_common_post_save_hook,
+		post_save_hook
+	);
+
 	opt_group_common.add_entry_filename(
 		opt_common_command_dir,
 		m_command_dir
@@ -310,6 +330,11 @@ Sobby::Server::Server(int argc, char* argv[]):
 				"autosave_interval", 0
 			);
 
+		if(post_save_hook.empty())
+			post_save_hook = entry.get_value<std::string>(
+				"post_save_hook", ""
+			);
+
 		if(password.empty() )
 			password = entry.get_value<Glib::ustring>(
 				"password", ""
@@ -330,6 +355,7 @@ Sobby::Server::Server(int argc, char* argv[]):
 		if(autosave_folder.empty()) autosave_folder = "";
 		if(autosave_file.empty() ) autosave_file = "autosave.obby";
 		if(autosave_interval == 0) autosave_interval = 0;
+		if(post_save_hook.empty()) post_save_hook = "";
 		if(password.empty() ) password = "";
 		if(m_command_dir.empty()) m_command_dir = "";
 		if(session.empty()) session = "";
@@ -349,6 +375,7 @@ Sobby::Server::Server(int argc, char* argv[]):
 		entry.set_value("autosave_file", autosave_file);
 		entry.set_value("autosave_directory", autosave_folder);
 		entry.set_value("autosave_interval", autosave_interval);
+		entry.set_value("post_save_hook", post_save_hook);
 		entry.set_value("password", password);
 		entry.set_value("command_directory", m_command_dir);
 		entry.set_value("session", session);
@@ -406,41 +433,39 @@ Sobby::Server::Server(int argc, char* argv[]):
 
 	m_server->set_global_password(password);
 
-	if(autosave_interval > 0)
+	if(autosave_folder.empty())
 	{
-		if(autosave_folder.empty())
+		m_autosaver.reset(
+			new AutoSaver(
+				*m_server,
+				autosave_file,
+				autosave_interval,
+				post_save_hook
+			)
+		);
+
+		m_autosaver->error_event().connect(
+			sigc::mem_fun(*this, &Server::on_autosave_error) );
+	}
+	else
+	{
+		if(!Glib::file_test(autosave_folder, Glib::FILE_TEST_IS_DIR))
 		{
-			m_autosaver.reset(
-				new AutoSaver(
-					*m_server,
-					autosave_file,
-					autosave_interval
-				)
-			);
-
-			m_autosaver->error_event().connect(
-				sigc::mem_fun(*this, &Server::on_autosave_error) );
+			obby::format_string str("'%0%' is not a directory");
+			str << autosave_folder;
+			throw std::runtime_error(str.str()); 
 		}
-		else
-		{
-			if(!Glib::file_test(autosave_folder, Glib::FILE_TEST_IS_DIR))
-			{
-				obby::format_string str("'%0%' is not a directory");
-				str << autosave_folder;
-				throw std::runtime_error(str.str()); 
-			}
 
-			m_autosave_folder.reset(
-				new AutoSaveFolder(
-					*m_server,
-					autosave_folder,
-					autosave_interval
-				)
-			);
+		m_autosave_folder.reset(
+			new AutoSaveFolder(
+				*m_server,
+				autosave_folder,
+				autosave_interval
+			)
+		);
 
-			m_autosave_folder->error_event().connect(
-				sigc::mem_fun(*this, &Server::on_autosave_error) );
-		}
+		m_autosave_folder->error_event().connect(
+			sigc::mem_fun(*this, &Server::on_autosave_error) );
 	}
 
 	m_command_executer.reset(new CommandExecuter(*this, *m_server) );
@@ -512,6 +537,17 @@ void Sobby::Server::run()
 	m_main_loop->run();
 }
 
+void Sobby::Server::quit()
+{
+	m_main_loop->quit();
+}
+
+void Sobby::Server::save()
+{
+	if(m_autosaver.get()) m_autosaver->save();
+	if(m_autosave_folder.get()) m_autosave_folder->save();
+}
+
 bool Sobby::Server::on_stdin(Glib::IOCondition condition)
 {
 	std::string line;
